import pandas as pd

import datetime

from qcpv import filter_single, filter_across

"""
example of how to call qcpv.py
"""

#% set params
set_latitude     = 52.11 #KNMI weather station de Bilt
set_longitude    = 5.18  #KNMI weather station de Bilt
set_altitude     = 5
set_timezone     = 'UTC'
set_city         = 'UTRECHT'
set_country_code = 'NL'
set_kpv_threshold= 1.4
coef_inv         = 0.96
coef_inv_norm    = 0.9637
coef_temp        = -0.0035

set_temperature_model_parameters = {'a': -2.98, 'b': -0.0471, 'deltaT': 1}
set_max_consecutive_period       = 20
minimal_daily_data_availabilty   = 0.5


#% open files
'''
df_weather          = pd.read_csv(insert_weather_file, parse_dates=['DateTime'])
df_metadata         = pd.read_csv(insert_metadate_file)
df_pv_rawdata       = pd.read_csv(insert_pv_data, parse_dates=['DateTime'])
'''

#% filter pv power measurements, single filter
df_merge_systems_single_filter_applied = pd.DataFrame()

for system_id in df_pv_rawdata.columns[:1]:
    df_system = pd.DataFrame()    
    df_system = df_pv_rawdata[[system_id]].copy(deep=True)
    
    tilt = df_metadata.loc[df_metadata['ID'] == system_id]['tilt'].item()
    azimuth = df_metadata.loc[df_metadata['ID'] == system_id]['azimuth'].item()
    dc_capacity = df_metadata.loc[df_metadata['ID'] == system_id]['estimated_dc_capacity'].item()
    ac_capacity = df_metadata.loc[df_metadata['ID'] == system_id]['estimated_ac_capacity'].item()
    
#availability filter
    df_system = filter_single.min_availability(df_system,set_latitude,set_longitude,set_timezone,minimal_daily_data_availabilty)

#night time filter 
    df_system = filter_single.night_time(df_system,df_weather,set_latitude,set_longitude,set_altitude,set_timezone,tilt,azimuth,dc_capacity,coef_temp,coef_inv,coef_inv_norm,set_temperature_model_parameters,set_city,set_country_code)

#around sunrise/sunset filter
    df_system = filter_single.around_sundown(df_system,set_latitude,set_longitude,set_altitude,set_timezone,set_city,set_country_code)

#lower limit filter
    df_system = filter_single.lower_limit(df_system)

#upper limit filter
    df_system = filter_single.upper_limit(df_system,df_weather,set_latitude,set_longitude,set_altitude,set_timezone,tilt,azimuth,dc_capacity,ac_capacity,coef_temp,coef_inv,coef_inv_norm,set_temperature_model_parameters,set_city,set_country_code,set_kpv_threshold)

#linear limit filter
    df_system = filter_single.consecutive_period(df_system,set_latitude,set_longitude,set_timezone,set_max_consecutive_period)

#availability filter
    df_system = filter_single.min_availability(df_system,set_latitude,set_longitude,set_timezone,minimal_daily_data_availabilty)

#persistence filter
    df_system = filter_single.persistence(df_system,set_latitude,set_longitude,set_timezone,dc_capacity)

    df_merge_systems_single_filter_applied = pd.merge(df_merge_systems_single_filter_applied, df_system, left_index=True, right_index=True, how='outer')


#% filter pv power measurements, across filter
#daily energy ratio filter
df_merge_systems_across_filter_applied = filter_across.daily_energy_ratio(df_merge_systems_single_filter_applied,df_metadata,df_weather,set_latitude,set_longitude,set_timezone,set_altitude,coef_temp,coef_inv,coef_inv_norm)

